@@ -124,12 +124,16 @@ def encrypt(
 ) -> Optional[str]:
     """Wrapper for the main function of the encrypt workflow."""
 
-    if config.sign_encrypted_data and not dry_run:
-        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
-            "Please enter your gpg private key password:", passphrase_cmd
+    # Retrieve the user's PGP key password (needed to sign the data).
+    kwargs["passphrase"] = (
+        None
+        if dry_run
+        else get_passphrase_from_cmd_or_prompt(
+            "Please enter your PGP private key password:", passphrase_cmd
         )
-    else:
-        kwargs["passphrase"] = None
+    )
+
+    # Run the encrypt workflow.
     try:
         return workflows_encrypt(
             *files,
@@ -220,16 +224,16 @@ class Cli(CliWithSubcommands):
     description = __doc__.format(URL_READTHEDOCS, URL_GITLAB_ISSUES)
     version = VERSION_WITH_DEPS
     config = load_config_and_check_app_is_up_to_date()
-    passphrase_override = dict(
-        help="Instead of asking for passphrase, get it from an external command "
+    passphrase_override = {
+        "help": "Instead of asking for passphrase, get it from an external command "
         "(passphrase must be returned to the standard output).",
-        name="passphrase-cmd",
-        dest="passphrase_cmd",
-        type=str,
-    )
-    dry_run_override = dict(
-        help="Perform checks on the input data, without running the actual command."
-    )
+        "name": "passphrase-cmd",
+        "dest": "passphrase_cmd",
+        "type": str,
+    }
+    dry_run_override = {
+        "help": "Perform checks on the input data, without running the actual command."
+    }
     subcommands = (
         Subcommand(
             decorate(
@@ -238,47 +242,48 @@ class Cli(CliWithSubcommands):
                 lazy_partial(progress=CliProgress),
             ),
             overrides={
-                "files": dict(help="Input file(s) or directories."),
-                "sender": dict(
-                    help="Fingerprint, key ID or email associated "
+                "files": {"help": "Input file(s) or directories."},
+                "sender": {
+                    "help": "Fingerprint, key ID or email associated "
                     "with GPG key of data sender.",
-                    alias="-s",
-                ),
-                "recipient": dict(
-                    help="Fingerprint, key ID or email associated with "
+                    "alias": "-s",
+                },
+                "recipient": {
+                    "help": "Fingerprint, key ID or email associated with "
                     "GPG key of data recipient(s).",
-                    alias="-r",
-                ),
-                "dtr_id": dict(
-                    help="Data Transfer Request (DTR) ID (optional if "
+                    "alias": "-r",
+                },
+                "dtr_id": {
+                    "help": "Data Transfer Request (DTR) ID (optional if "
                     "`verify_dtr` is disabled in settings).",
-                    alias="-t",
-                ),
-                "purpose": dict(
-                    help="Purpose of the DTR (PRODUCTION, TEST). "
+                    "alias": "-t",
+                },
+                "purpose": {
+                    "help": "Purpose of the DTR (PRODUCTION, TEST). "
                     "Mandatory only if `transfer_id` is specified."
-                ),
-                "force": dict(
-                    help="Ignore errors about missing disk space", alias="-f"
-                ),
-                "output": dict(
-                    help="Output path (directory path and/or file name) of "
+                },
+                "force": {
+                    "help": "Ignore errors about missing disk space",
+                    "alias": "-f",
+                },
+                "output": {
+                    "help": "Output path (directory path and/or file name) of "
                     "the encrypted package. If no directory path is specified, "
                     "the output package is saved in the current working "
                     "directory. If this argument is missing or the path is a "
                     "directory, the file name is generated based on the "
                     "current date and an optional suffix.",
-                    default=None,
-                    alias="-o",
-                ),
-                "output_suffix": dict(help="Output file name suffix (optional)"),
+                    "default": None,
+                    "alias": "-o",
+                },
+                "output_suffix": {"help": "Output file name suffix (optional)"},
                 "dry_run": dry_run_override,
-                "compression_level": dict(
-                    help="Compression level for inner tarball in the range "
+                "compression_level": {
+                    "help": "Compression level for inner tarball in the range "
                     "0 (no compression) to 9 (highest compression). "
                     "Higher compression levels require more computing "
                     "time."
-                ),
+                },
                 "passphrase": passphrase_override,
             },
         ),
@@ -289,26 +294,26 @@ class Cli(CliWithSubcommands):
                 lazy_partial(progress=CliProgress),
             ),
             overrides={
-                "files": dict(help="Path(s) to encrypted package(s)"),
-                "protocol": dict(
-                    help=f"The protocol for the file transfer."
+                "files": {"help": "Path(s) to encrypted package(s)"},
+                "protocol": {
+                    "help": f"The protocol for the file transfer."
                     f"Currently available: {', '.join(available_protocols)}",
-                    type=parse_protocol,
-                    alias="-p",
-                ),
-                "protocol_args": dict(
-                    help="Protocol specific arguments. "
+                    "type": parse_protocol,
+                    "alias": "-p",
+                },
+                "protocol_args": {
+                    "help": "Protocol specific arguments. "
                     "Must be passed as a json string",
-                    type=parse_protocol_args,
-                ),
-                "connection": dict(
-                    help="Instead of the option 'protocol', load a connection "
+                    "type": parse_protocol_args,
+                },
+                "connection": {
+                    "help": "Instead of the option 'protocol', load a connection "
                     "named by the argument of this option to use the "
                     "protocol and protocol args from the config. The "
                     "protocol args can be overwritten by the "
                     "protocol_args option"
-                ),
-                "passphrase_cmd": dict(help=passphrase_override["help"]),
+                },
+                "passphrase_cmd": {"help": passphrase_override["help"]},
                 "dry_run": dry_run_override,
             },
         ),
@@ -317,14 +322,14 @@ class Cli(CliWithSubcommands):
                 decrypt, partial(config=config), lazy_partial(progress=CliProgress)
             ),
             overrides={
-                "files": dict(help="Path(s) to encrypted package(s)"),
-                "output_dir": dict(
-                    help="Path to the directory where package content is saved after decryption. "
+                "files": {"help": "Path(s) to encrypted package(s)"},
+                "output_dir": {
+                    "help": "Path to the directory where package content is saved after decryption. "
                     "If no path is specified, current working directory is taken.",
-                    default=os.getcwd(),
-                    alias="-o",
-                ),
-                "decrypt_only": dict(help="Skip extraction."),
+                    "default": os.getcwd(),
+                    "alias": "-o",
+                },
+                "decrypt_only": {"help": "Skip extraction."},
                 "dry_run": dry_run_override,
                 "passphrase": passphrase_override,
             },
@@ -339,7 +344,7 @@ class Cli(CliWithSubcommands):
         ),
         Subcommand(
             decorate(verify_keylengths_and_upload_keys, partial(config=config)),
-            overrides={"fingerprints": dict(help="Fingerprints to upload")},
+            overrides={"fingerprints": {"help": "Fingerprints to upload"}},
         ),
     )
 
