@@ -349,7 +349,7 @@ def arguments_by_signature(
             positional,
         )
         default = p_overrides.get("default", p.default)
-        args = dict(help=p_overrides.get("help"))
+        args = {"help": p_overrides.get("help")}
         t = p_overrides.get("type", p.annotation)
         if t is inspect.Signature.empty:
             raise ValueError(f"Argument {arg_names[0]} has no type hint")
