@@ -310,8 +310,8 @@ def encrypt_and_sign(
     output: gpg.cmd.OSource,
     gpg_store: GPGStore,
     recipients_fingerprint: List[str],
-    signature_fingerprint: Optional[str] = None,
-    passphrase: Optional[Secret[str]] = None,
+    signature_fingerprint: str,
+    passphrase: Secret[str],
     always_trust: bool = True,
 ) -> None:
     """Encrypt input data with a PGP public key and sign it with a private key.
@@ -328,12 +328,9 @@ def encrypt_and_sign(
     :param gpg_store: directory containing GnuPG keyrings as gnupg object.
     :param recipients_fingerprint: fingerprint of public key(s) with which
         the data should be encrypted.
-    :param signature_fingerprint: fingerprint of private key with which the
-        data should be signed. If the parameter value is set to None the
-        encrypted file is not signed.
-    :param passphrase: password associated to 'signature_fingerprint'. This
-        parameter value can be set to None if the encrypted file should not be
-        signed.
+    :param signature_fingerprint: fingerprint of private PGP key with which to
+        sign the data.
+    :param passphrase: password of private PGP key. Needed to sign the data.
     :param always_trust: if False, the encryption key must be signed by the
         local user.
     :raises UserError:
@@ -345,15 +342,24 @@ def encrypt_and_sign(
             source=source,
             recipients=recipients_fingerprint,
             output=output,
+            sign=signature_fingerprint,
             passphrase=reveal(passphrase),
             trust_model=gpg.TrustModel.always if always_trust else gpg.TrustModel.pgp,
-            sign=signature_fingerprint,
             compress_algo=gpg.CompressAlgo.NONE,
         )
-    except gpg.GPGError:
-        raise UserError(
-            "Encryption failed. Maybe you entered a wrong passphrase."
-        ) from None
+    except gpg.GPGError as e:
+        # Note: this function is only called from the encryption workflow after
+        # checking that the password of the sender's key is correct.
+        # As a result, the GPG error should never be triggered by a wrong password.
+        msg = ["Encryption failed."]
+        if not always_trust:
+            msg.append(
+                "If the recipient key is not 'Trusted', you need to either "
+                "sign it with an external tool (e.g. GnuPG) or enable "
+                "'Always trust recipient key' in the settings."
+            )
+        msg.append(f"Original error: {e}")
+        raise UserError(" ".join(msg)) from e
 
 
 def get_recipient_email(key: gpg.Key) -> str:
@@ -384,9 +390,7 @@ def decrypt(
     :param source: data to decrypt.
     :param output: file where the decrypted data should be written to.
     :param gpg_store: directory containing GnuPG keyrings as gnupg object.
-    :param passphrase: password associated to 'signature_fingerprint'. This
-        parameter value can be set to None if the encrypted file should not be
-        signed.
+    :param passphrase: password of the PGP decryption key (recipient key).
     :return: fingerprint or keyid of the signee's key.
     :raises UserError: if the data could not be decrypted.
     """
