@@ -86,7 +86,7 @@ class SelectionButton(QtWidgets.QPushButton):
         super().__init__(label)
         self.setEnabled(False)
         self._selection_model = selection_model
-        selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
+        selection_model.selectionChanged.connect(self.selection_changed)
 
     def selection_changed(self) -> None:
         # Following works better than using 'QItemSelection', especially in
@@ -106,7 +106,7 @@ class SelectionAction(Action):
         self.setEnabled(False)
         self._selection_enabled = True
         self._selection_model = selection_model
-        self._selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
+        self._selection_model.selectionChanged.connect(self.selection_changed)
 
     def enable_selection(self, enabled: bool) -> None:
         self._selection_enabled = enabled
@@ -147,7 +147,7 @@ class ConsoleWidget(QtWidgets.QGroupBox, IconRepainterWidget):
         self.textbox.setReadOnly(True)
         btn_clear_console = PushButton(":icon/feather/slash.png", "", self)
         btn_clear_console.setToolTip("Clear console")
-        btn_clear_console.clicked.connect(self.clear)  # type: ignore
+        btn_clear_console.clicked.connect(self.clear)
         layout = QtWidgets.QHBoxLayout(self)
         layout.addWidget(self.textbox)
         layout.addWidget(btn_clear_console, alignment=QtCore.Qt.AlignmentFlag.AlignTop)
@@ -179,18 +179,18 @@ class PathInput:
             f":icon/feather/{'folder' if directory else 'file'}.png", "", parent
         )
         self.btn.setToolTip("Change location")
-        self.btn.clicked.connect(partial(self._update_location, directory))  # type: ignore
+        self.btn.clicked.connect(partial(self._update_location, directory))
         if btn_clear:
             # Add additional button to allow clearing the selected path.
             self.btn_clear = PushButton(":icon/feather/slash.png", "", parent)
             self.btn_clear.setToolTip("Clear location")
-            self.btn_clear.clicked.connect(self._clear_location)  # type: ignore
+            self.btn_clear.clicked.connect(self._clear_location)
         self.update_path(path)
 
     def update_path(self, path: Optional[Path]) -> None:
         self.path = path
         self.text.setText("" if path is None else str(path))
-        self.text.editingFinished.emit()  # type: ignore
+        self.text.editingFinished.emit()
 
     def _update_location(self, directory: bool) -> None:
         if self.path and self.path.exists():
@@ -218,7 +218,7 @@ class PathInput:
 
     def on_path_change(self, fn: Callable[[Optional[Path]], None]) -> None:
         """Run callback when path changes."""
-        self.text.editingFinished.connect(lambda: fn(self.path))  # type: ignore
+        self.text.editingFinished.connect(lambda: fn(self.path))
 
 
 class BaseTab(IconRepainterWidget):
@@ -255,15 +255,15 @@ class BaseTab(IconRepainterWidget):
 
         # On pressed button, make sure that the focus switches to that
         # button (Mac specific issue)
-        self.btn_test.pressed.connect(self.btn_test.setFocus)  # type: ignore
-        self.btn_test.clicked.connect(partial(action, dry_run=True))  # type: ignore
+        self.btn_test.pressed.connect(self.btn_test.setFocus)
+        self.btn_test.clicked.connect(partial(action, dry_run=True))
         # pylint:disable=attribute-defined-outside-init
         self.btn_run = BaseTab._create_disabled_button(action_name)
 
         # On pressed button, make sure that the focus switches to that
         # button (Mac specific issue)
-        self.btn_run.pressed.connect(self.btn_run.setFocus)  # type: ignore
-        self.btn_run.clicked.connect(action)  # type: ignore
+        self.btn_run.pressed.connect(self.btn_run.setFocus)
+        self.btn_run.clicked.connect(action)
         hbox_layout(self.btn_test, self.btn_run, parent=self.run_panel)
 
     def run_workflow_thread(
@@ -292,10 +292,10 @@ def get_text_input(
     )
     ok_btn = buttons.addButton(QtWidgets.QDialogButtonBox.StandardButton.Ok)
     ok_btn.setEnabled(False)
-    buttons.accepted.connect(dialog.accept)  # type: ignore
-    buttons.rejected.connect(dialog.reject)  # type: ignore
+    buttons.accepted.connect(dialog.accept)
+    buttons.rejected.connect(dialog.reject)
     user_input = LineEdit()
-    user_input.textChanged.connect(lambda t: ok_btn.setEnabled(bool(t)))  # type: ignore
+    user_input.textChanged.connect(lambda t: ok_btn.setEnabled(bool(t)))
     if password:
         user_input.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
     vbox_layout(QtWidgets.QLabel(msg), user_input, buttons, parent=dialog)
@@ -367,9 +367,9 @@ def create_slider(
     def update_text(value: int) -> None:
         widget_value.setText(str(value))
 
-    slider.valueChanged.connect(update_text)  # type: ignore
+    slider.valueChanged.connect(update_text)
     if on_change is not None:
-        slider.valueChanged.connect(on_change)  # type: ignore
+        slider.valueChanged.connect(on_change)
 
     return slider, widget_value
 
@@ -404,7 +404,7 @@ def layout_add(
 
 
 def grid_layout(
-    *widgets: Sequence[Union[QtWidgets.QWidget, GridLayoutCell, None]],
+    *widgets: Sequence[Union[WIDGET_OR_LAYOUT, GridLayoutCell, None]],
     parent: Optional[QtWidgets.QWidget] = None,
     min_col_width: Optional[Sequence[int]] = None,
 ) -> QtWidgets.QGridLayout:
