@@ -41,7 +41,7 @@ class DecryptTab(BaseTab):
 
     def create_files_panel(self) -> QtWidgets.QGroupBox:
         box = ArchiveOnlyFileSelectionWidget(title="Files to decrypt", parent=self)
-        box.file_list_model.layoutChanged.connect(  # type: ignore
+        box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "decrypt_files", box.get_list())
         )
         return box
@@ -52,7 +52,7 @@ class DecryptTab(BaseTab):
         decompress = QtWidgets.QCheckBox("Decompress", box)
         decompress.setStatusTip("Decompress data after decryption")
         decompress.setChecked(not self.app_data.decrypt_decrypt_only)
-        decompress.stateChanged.connect(  # type: ignore
+        decompress.stateChanged.connect(
             lambda state: setattr(
                 self.app_data,
                 "decrypt_decrypt_only",
@@ -83,15 +83,15 @@ class DecryptTab(BaseTab):
             pw = None
         self.run_workflow_thread(
             decrypt.decrypt,
-            f_kwargs=dict(
-                files=self.app_data.decrypt_files,
-                output_dir=str(self.app_data.decrypt_output_location),
-                config=self.app_data.config,
-                decrypt_only=self.app_data.decrypt_decrypt_only,
-                passphrase=pw,
-                dry_run=dry_run,
-                progress=GuiProgress(self.progress_bar.setValue),
-            ),
+            f_kwargs={
+                "files": self.app_data.decrypt_files,
+                "output_dir": str(self.app_data.decrypt_output_location),
+                "config": self.app_data.config,
+                "decrypt_only": self.app_data.decrypt_decrypt_only,
+                "passphrase": pw,
+                "dry_run": dry_run,
+                "progress": GuiProgress(self.progress_bar.setValue),
+            },
             capture_loggers=(decrypt.logger,),
             ignore_exceptions=True,
             report_config=self.app_data.config,
