@@ -88,7 +88,7 @@ class EncryptTab(BaseTab):
 
     def create_files_panel(self) -> QtWidgets.QGroupBox:
         box = DirectoryAndFileSelectionWidget(title="Data to encrypt", parent=self)
-        box.file_list_model.layoutChanged.connect(  # type: ignore
+        box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "encrypt_files", box.get_list())
         )
         return box
@@ -161,10 +161,10 @@ class EncryptTab(BaseTab):
             recipients_output_view.clearSelection()
 
         # Connect actions.
-        recipients_btn_add.clicked.connect(add_recipient)  # type: ignore
-        recipients_btn_remove.clicked.connect(remove_recipient)  # type: ignore
-        recipients_output_model.dataChanged.connect(update_recipients)  # type: ignore
-        sender_widget.currentIndexChanged.connect(update_sender)  # type: ignore
+        recipients_btn_add.clicked.connect(add_recipient)
+        recipients_btn_remove.clicked.connect(remove_recipient)
+        recipients_output_model.dataChanged.connect(update_recipients)
+        sender_widget.currentIndexChanged.connect(update_sender)
         # Set the default value for the sender
         update_sender(sender_widget.currentIndex())
         grid_layout(
@@ -220,7 +220,7 @@ class EncryptTab(BaseTab):
         output_location.setStatusTip("Destination folder for the encrypted package")
 
         # Add actions
-        output_suffix.editingFinished.connect(  # type: ignore
+        output_suffix.editingFinished.connect(
             lambda: setattr(
                 self.app_data, "encrypt_package_name_suffix", output_suffix.text()
             )
@@ -249,7 +249,7 @@ class EncryptTab(BaseTab):
         ignore_disk_space_error.setChecked(
             self.app_data.encrypt_ignore_disk_space_error
         )
-        ignore_disk_space_error.stateChanged.connect(  # type: ignore
+        ignore_disk_space_error.stateChanged.connect(
             lambda state: setattr(
                 self.app_data,
                 "encrypt_ignore_disk_space_error",
@@ -302,8 +302,8 @@ class EncryptTab(BaseTab):
                 self.app_data.encrypt_transfer_id = None
                 purpose_label.setText("Purpose")
 
-        transfer_id.textChanged.connect(on_transfer_id_changed)  # type: ignore
-        purpose.currentTextChanged.connect(  # type: ignore
+        transfer_id.textChanged.connect(on_transfer_id_changed)
+        purpose.currentTextChanged.connect(
             lambda text: setattr(
                 self.app_data, "encrypt_purpose", None if text == "" else Purpose(text)
             )
@@ -316,39 +316,43 @@ class EncryptTab(BaseTab):
         return group_box
 
     def encrypt(self, dry_run: bool = False) -> None:
-        if not dry_run and self.app_data.config.sign_encrypted_data:
-            pw = get_pass_input(self, "Enter password for your GPG key")
-            if pw is None:
-                return
-        else:
-            pw = None
+        """Run the encrypt workflow in a separate thread."""
 
-        def update_transfer_files(path: Optional[str]) -> None:
+        def update_files_to_transfer_in_transfer_tab(path: Optional[str]) -> None:
             if path is not None:
                 self.app_data.transfer_files.setStringList([path])
-                self.app_data.transfer_files.layoutChanged.emit()  # type: ignore
+                self.app_data.transfer_files.layoutChanged.emit()
                 self.console.append(
                     "<strong>Added the newly created package to the 'Transfer' tab.</strong>"
                 )
 
+        # Retrieve the user's PGP key password (needed to sign the data).
+        if not dry_run:
+            passphrase = get_pass_input(self, "Please enter your PGP key password")
+            if passphrase is None:
+                return
+        else:
+            passphrase = None
+
+        # Run the encrypt workflow in a separate thread.
         self.run_workflow_thread(
             encrypt_workflow,
-            f_kwargs=dict(
-                files=self.app_data.encrypt_files,
-                capture_loggers=(encrypt.logger,),
-                sender=self.app_data.encrypt_sender,
-                recipient=self.app_data.encrypt_recipients,
-                dtr_id=self.app_data.encrypt_transfer_id,
-                config=self.app_data.config,
-                passphrase=pw,
-                output=self.app_data.encrypt_output_location,
-                output_suffix=self.app_data.encrypt_package_name_suffix,
-                dry_run=dry_run,
-                compression_level=self.app_data.encrypt_compression_level,
-                purpose=self.app_data.encrypt_purpose,
-                progress=GuiProgress(self.progress_bar.setValue),
-            ),
-            signals={"result": update_transfer_files},
+            f_kwargs={
+                "files": self.app_data.encrypt_files,
+                "capture_loggers": (encrypt.logger,),
+                "sender": self.app_data.encrypt_sender,
+                "recipient": self.app_data.encrypt_recipients,
+                "dtr_id": self.app_data.encrypt_transfer_id,
+                "config": self.app_data.config,
+                "passphrase": passphrase,
+                "output": self.app_data.encrypt_output_location,
+                "output_suffix": self.app_data.encrypt_package_name_suffix,
+                "dry_run": dry_run,
+                "compression_level": self.app_data.encrypt_compression_level,
+                "purpose": self.app_data.encrypt_purpose,
+                "progress": GuiProgress(self.progress_bar.setValue),
+            },
+            signals={"result": update_files_to_transfer_in_transfer_tab},
             ignore_exceptions=True,
             report_config=self.app_data.config,
             force=self.app_data.encrypt_ignore_disk_space_error,
