@@ -75,14 +75,14 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
 
     def _create_add_files_action(self) -> QAction:
         action = Action(":icon/feather/file-plus.png", "Add file", self)
-        action.triggered.connect(self._add_files)  # type: ignore
+        action.triggered.connect(self._add_files)
         return action
 
     def _create_remove_selected_action(self) -> QAction:
         def clear_selected() -> None:
             for index in self.file_list_view.selectedIndexes():
                 self.file_list_model.removeRows(index.row(), 1)
-            self.file_list_model.layoutChanged.emit()  # type: ignore
+            self.file_list_model.layoutChanged.emit()
 
         action = SelectionAction(
             ":icon/feather/file-minus.png",
@@ -90,7 +90,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
             self,
             selection_model=self.file_list_view.selectionModel(),
         )
-        action.triggered.connect(clear_selected)  # type: ignore
+        action.triggered.connect(clear_selected)
         return action
 
     def _create_clear_list_action(self) -> QAction:
@@ -98,10 +98,10 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
             # Clear the selection BEFORE resetting the model
             self.file_list_view.selectionModel().clearSelection()
             self.file_list_model.setStringList([])
-            self.file_list_model.layoutChanged.emit()  # type: ignore
+            self.file_list_model.layoutChanged.emit()
 
         action = Action(":icon/feather/trash-2.png", "Clear list", self)
-        action.triggered.connect(clear_list)  # type: ignore
+        action.triggered.connect(clear_list)
         return action
 
     def _update_paths(self, paths: Iterable[str]) -> None:
@@ -111,7 +111,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox, IconRepainterWidget):
         self.file_list_model.setStringList(
             sorted(set(self.file_list_model.stringList()) | paths)
         )
-        self.file_list_model.layoutChanged.emit()  # type: ignore
+        self.file_list_model.layoutChanged.emit()
 
     def _add_files(self) -> None:
         dialog = QtWidgets.QFileDialog(self)
@@ -151,7 +151,7 @@ class DirectoryAndFileSelectionWidget(FileSelectionWidget):
             self._update_paths((directory,))
 
         action = Action(":icon/feather/folder-plus.png", "Add directory", self)
-        action.triggered.connect(add_directory)  # type: ignore
+        action.triggered.connect(add_directory)
         return action
 
 
