@@ -76,23 +76,23 @@ class KeysTab(IconRepainterWidget):
 
         self.priv_keys_view = QtWidgets.QListView()
         self.priv_keys_view.setModel(self.app_data.priv_keys_model)
-        self.priv_keys_view.selectionModel().currentChanged.connect(  # type: ignore
+        self.priv_keys_view.selectionModel().currentChanged.connect(
             self._update_display
         )
 
         self.pub_keys_view = QtWidgets.QListView()
         self.pub_keys_view.setModel(self.app_data.pub_keys_model)
-        self.pub_keys_view.selectionModel().currentChanged.connect(self._update_display)  # type: ignore
+        self.pub_keys_view.selectionModel().currentChanged.connect(self._update_display)
         self.pub_keys_view.setSelectionMode(
             QtWidgets.QAbstractItemView.SelectionMode.ExtendedSelection
         )
 
         # When item is selected in the public/private key list, clear
         # the selection in the other list.
-        self.priv_keys_view.selectionModel().currentChanged.connect(  # type: ignore
+        self.priv_keys_view.selectionModel().currentChanged.connect(
             lambda: self.pub_keys_view.selectionModel().clear()
         )
-        self.pub_keys_view.selectionModel().currentChanged.connect(  # type: ignore
+        self.pub_keys_view.selectionModel().currentChanged.connect(
             lambda: self.priv_keys_view.selectionModel().clear()
         )
 
@@ -101,7 +101,7 @@ class KeysTab(IconRepainterWidget):
             "Generate new private/public key",
             self,
         )
-        action_generate_key.triggered.connect(  # type: ignore
+        action_generate_key.triggered.connect(
             lambda: KeyGenDialog(parent=self, app_data=app_data).show()
         )
         action_refresh_keys = Action(
@@ -124,10 +124,10 @@ class KeysTab(IconRepainterWidget):
                     msg_prefix="Approval status of PGP keys could not be "
                     f"retrieved from \n'{self.app_data.config.dcc_portal_url}'.",
                 ),
-                signals=dict(result=self.update_display_selected_pub_key),
+                signals={"result": self.update_display_selected_pub_key},
             )
 
-        action_refresh_keys.triggered.connect(refresh_keys)  # type: ignore
+        action_refresh_keys.triggered.connect(refresh_keys)
 
         toolbar = ToolBar("Key management", self)
         toolbar.addAction(action_generate_key)
@@ -260,7 +260,7 @@ class KeysTab(IconRepainterWidget):
             ),
         )
         for action, fn in functions_by_action:
-            action.triggered.connect(fn)  # type: ignore
+            action.triggered.connect(fn)
             yield action
 
     def get_selected_keys(self) -> Tuple[gpg.Key, ...]:
@@ -290,14 +290,14 @@ class KeysTab(IconRepainterWidget):
 
             run_thread(
                 crypt.download_keys,
-                f_kwargs=dict(
-                    key_identifiers=[key.fingerprint for key in keys_to_update],
-                    keyserver=self.app_data.config.keyserver_url,
-                    gpg_store=self.app_data.config.gpg_store,
-                ),
+                f_kwargs={
+                    "key_identifiers": [key.fingerprint for key in keys_to_update],
+                    "keyserver": self.app_data.config.keyserver_url,
+                    "gpg_store": self.app_data.config.gpg_store,
+                },
                 report_config=self.app_data.config,
                 forward_errors=warning_callback("GPG key update error"),
-                signals=dict(result=on_result),
+                signals={"result": on_result},
             )
 
     def import_key(self) -> None:
@@ -405,21 +405,21 @@ class KeysTab(IconRepainterWidget):
                 ):
                     run_thread(
                         upload_keys_workflow.upload_keys,
-                        f_kwargs=dict(
-                            fingerprints=[key.fingerprint],
-                            verify_key=cb.isChecked(),
-                            config=self.app_data.config,
-                        ),
+                        f_kwargs={
+                            "fingerprints": [key.fingerprint],
+                            "verify_key": cb.isChecked(),
+                            "config": self.app_data.config,
+                        },
                         capture_loggers=(upload_keys_workflow.logger,),
                         report_config=self.app_data.config,
                         forward_errors=warning_callback("GPG key upload error"),
-                        signals=dict(
-                            result=lambda _: open_info_msgbox(
+                        signals={
+                            "result": lambda _: open_info_msgbox(
                                 "Key has been successfully uploaded to keyserver.",
                                 title="Sent PGP keys",
                                 parent=self.parentWidget(),
                             )
-                        ),
+                        },
                     )
 
     def _update_display(self, index: QtCore.QModelIndex) -> None:
