@@ -97,7 +97,7 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
         action_exit = Action(":icon/feather/log-out.png", "&Exit", self)
         action_exit.setShortcut(QtGui.QKeySequence("Ctrl+Q"))
         action_exit.setStatusTip("Exit application")
-        action_exit.triggered.connect(self.close)  # type: ignore
+        action_exit.triggered.connect(self.close)
 
         menu = self.menuBar()
         menu.setNativeMenuBar(not is_macos())
@@ -109,17 +109,17 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
         action_help.setShortcut(
             QtGui.QKeySequence(QtGui.QKeySequence.StandardKey.HelpContents)
         )
-        action_help.triggered.connect(open_url(URL_READTHEDOCS))  # type: ignore
+        action_help.triggered.connect(open_url(URL_READTHEDOCS))
 
         action_bug_report = Action(
             ":icon/feather/alert-triangle.png", "&Report an Issue", self
         )
         action_bug_report.setStatusTip("Open online bug report form")
-        action_bug_report.triggered.connect(open_url(URL_GITLAB_ISSUES))  # type: ignore
+        action_bug_report.triggered.connect(open_url(URL_GITLAB_ISSUES))
 
         action_about = Action(":icon/feather/info.png", "&About", self)
         action_about.setStatusTip("Show info about application")
-        action_about.triggered.connect(self.show_about)  # type: ignore
+        action_about.triggered.connect(self.show_about)
 
         menu_help = menu.addMenu("&Help")
         menu_help.addAction(action_help)
@@ -131,8 +131,9 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
 
         # Clear focus on the currently selected widget. This is only needed
         # for the case where a user exits the app while still having the
-        # focus on field in the Settings Tab.
-        self.focusWidget().clearFocus()
+        # focus on a field in the Settings Tab.
+        if self.focusWidget():
+            self.focusWidget().clearFocus()
 
         # Compare the current in-memory config values to those present on disk
         # (in the user's config file). If they differ, ask the user whether
@@ -187,9 +188,9 @@ class MainWindow(QtWidgets.QMainWindow, IconRepainterWidget):
             get_warnings,
             f_kwargs={},
             report_config=self.app_data.config,
-            signals=dict(
-                result=lambda x: show_warning("Version check", x, self) if x else x
-            ),
+            signals={
+                "result": lambda x: show_warning("Version check", x, self) if x else x
+            },
         )
 
     def show_about(self) -> None:
