@@ -55,8 +55,8 @@ class TableModel(QtCore.QAbstractTableModel):
 
     def set_data(self, data: Sequence[Sequence[Any]]) -> None:
         self._data = tuple(sorted(tuple(x) for x in data))
-        self.layoutChanged.emit()  # type: ignore
-        self.dataChanged.emit(  # type: ignore
+        self.layoutChanged.emit()
+        self.dataChanged.emit(
             self.createIndex(0, 0),
             self.createIndex(self.rowCount(), self.columnCount()),
         )
@@ -118,7 +118,7 @@ class KeyValueListModel(QtCore.QAbstractListModel):
     def set_data(self, data: Iterable[Tuple[Hashable, Any]]) -> None:
         self._keyvalues = dict(data)
         self._keys = list(self._keyvalues.keys())
-        self.layoutChanged.emit()  # type: ignore
+        self.layoutChanged.emit()
 
     # Default value Qt.DisplayRole for index is not an int (upstream issue):
     def data(self, index, role) -> Optional[Hashable]:  # type: ignore
@@ -151,7 +151,14 @@ def new_sftp_connection() -> Protocol:
 
 
 def new_s3_connection() -> Protocol:
-    return s3.Protocol(host="", bucket="", access_key="", secret_key=Secret(""))
+    return s3.Protocol(  # nosec
+        host="",
+        secure=True,
+        bucket="",
+        access_key="",
+        secret_key=Secret(""),
+        session_token="",
+    )
 
 
 def new_liquid_files_connection() -> Protocol:
@@ -252,10 +259,15 @@ class AppData(ClassWithListener):
         """Check whether public keys from the user's local keyring are approved
         in the portal and store/update this information in the application's
         memory.
+        If no keys are present in the user's local PGP keyring, the request to
+        the Portal's API is skipped.
         """
-        self.pub_key_status = self.config.portal_api.get_key_status(
+        fingerprints = tuple(
             k.fingerprint for k in self.config.gpg_store.list_pub_keys()
         )
+        self.pub_key_status = (
+            self.config.portal_api.get_key_status(fingerprints) if fingerprints else {}
+        )
 
     def __post_init__(self) -> None:
         super().__init__()
