@@ -106,10 +106,7 @@ class SettingsTab(IconRepainterWidget):
                             cfg_field("always_trust_recipient_key"),
                             cfg_field("output_dir"),
                         ),
-                        (
-                            cfg_field("sign_encrypted_data"),
-                            cfg_field("package_name_suffix"),
-                        ),
+                        ((), cfg_field("package_name_suffix")),
                         ((label_field("PGP keys"),), ()),
                         (cfg_field("gpg_key_autodownload"), cfg_field("keyserver_url")),
                         (cfg_field("verify_key_approval"), cfg_field("gpg_home_dir")),
@@ -143,7 +140,7 @@ class SettingsTab(IconRepainterWidget):
             QtWidgets.QLineEdit, widget_register["keyserver_url"]
         )
         self._enable_checkbox_key_autodownload()
-        self.field_keyserver_url.textChanged.connect(  # type: ignore
+        self.field_keyserver_url.textChanged.connect(
             self._enable_checkbox_key_autodownload
         )
         self.config_proxy.refresh()
@@ -168,13 +165,13 @@ class SettingsTab(IconRepainterWidget):
         top_label.setWordWrap(True)
         reset_btn = QtWidgets.QPushButton("Reset", self)
         reset_btn.setStatusTip("Resets to your last persisted settings")
-        reset_btn.clicked.connect(  # type: ignore
+        reset_btn.clicked.connect(
             lambda: self.config_proxy.set_config(config.load_config())
         )
 
         defaults_btn = QtWidgets.QPushButton("Restore defaults", self)
         defaults_btn.setStatusTip("Reset all settings to their default values")
-        defaults_btn.clicked.connect(  # type: ignore
+        defaults_btn.clicked.connect(
             lambda: self.config_proxy.set_config(config.default_config())
         )
         layout = QtWidgets.QGridLayout()
@@ -190,7 +187,7 @@ class SettingsTab(IconRepainterWidget):
             self,
         )
         self.persist_btn.setStatusTip("Saves your current settings to the config file")
-        self.persist_btn.clicked.connect(self._save_config_to_disk)  # type: ignore
+        self.persist_btn.clicked.connect(self._save_config_to_disk)
         return self.persist_btn
 
     def _enable_checkbox_key_autodownload(self) -> None:
@@ -262,12 +259,11 @@ def reset_to_default_if_empty(widget: LineEdit) -> None:
     :param widget: text widget whose text is to be reset.
     """
     if not widget.text().strip():
-
         # Reset the in-memory value (AppData) and widget text to the default
         # value of the setting.
         config_key = widget.objectName()
         widget.setText(Config.get_default_value(config_key))
-        widget.editingFinished.emit()  # type: ignore
+        widget.editingFinished.emit()
 
         # Generate a pop-up that warns the user that the field has been
         # reset to its default value.
@@ -309,7 +305,7 @@ def widget_str(
     # check for resetting empty values to their default value is added to the
     # actions to perform after a field was edited by the user.
     if Config.is_mandatory_argument(config_key):
-        widget.editingFinished.connect(lambda: reset_to_default_if_empty(widget))  # type: ignore
+        widget.editingFinished.connect(lambda: reset_to_default_if_empty(widget))
 
     # Add regexp-based validation rules to the field. These rules are either
     # added via a post-edit check (i.e. when the user leaves the field, see
@@ -319,7 +315,7 @@ def widget_str(
     #         it contains a URL (FQDN = fully qualified domain name).
     if regex == REGEX_FQDN:
         # A check for the validity of the specified domain name is added.
-        widget.editingFinished.connect(  # type: ignore
+        widget.editingFinished.connect(
             lambda: check_hostname(regex, widget, status_tip)
         )
     # Case 2: the field is not a URL, but it has some specific validation
