@@ -1,4 +1,5 @@
 import enum
+import json
 import time
 from functools import partial
 from typing import Iterator, Optional, Sequence
@@ -14,6 +15,8 @@ from .component import (
     grid_layout,
     vbox_layout,
     hbox_layout,
+    GridLayoutCell,
+    NormalMessageBox,
 )
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .model import new_sftp_connection, AppData
@@ -25,6 +28,7 @@ from .ui_model_bind import (
     OptionalTextControl,
     OptionalPasswordControl,
     OptionalPathControl,
+    BoolControl,
 )
 from .. import protocols
 from ..core.error import UserError
@@ -121,25 +125,113 @@ class TransferProtocol(enum.Enum):
         args = data.transfer_protocol_args[S3]
 
         text_host = LineEdit()
+        text_host.setStatusTip("Host name of the S3-compatible server.")
+        text_host.setPlaceholderText("minioserver.example.net:9000")
         bind(args, "host", text_host, TextControl)
 
+        bool_secure = QtWidgets.QCheckBox()
+        bool_secure.setStatusTip("Whether to use a secure (TLS) connection or not.")
+        bool_secure.setChecked(True)
+        bind(args, "secure", bool_secure, BoolControl)
+        secure_layout = QtWidgets.QHBoxLayout()
+        secure_layout.addWidget(QtWidgets.QLabel("Use secure TLS connection"))
+        secure_layout.addWidget(bool_secure)
+
         text_bucket = LineEdit()
+        text_bucket.setStatusTip(
+            "Location (bucket) of the S3-compatible server to which the "
+            "file(s) should be uploaded."
+        )
         bind(args, "bucket", text_bucket, TextControl)
 
         text_access_key = LineEdit()
+        text_access_key.setStatusTip(
+            "Credentials for logging-in to the S3-compatible server: user access key."
+        )
         bind(args, "access_key", text_access_key, TextControl)
 
         text_secret_key = LineEdit()
         text_secret_key.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
+        text_secret_key.setStatusTip(
+            "Credentials for logging-in to the S3-compatible server: user secret key."
+        )
+        # To make left and right panels the same width.
+        text_secret_key.setMinimumWidth(400)
         bind(args, "secret_key", text_secret_key, OptionalPasswordControl)
 
+        text_session_token = LineEdit()
+        text_session_token.setStatusTip(
+            "Credentials for logging-in to the S3-compatible server: "
+            "temporary STS (Security Token Service) token."
+        )
+        bind(args, "session_token", text_session_token, OptionalTextControl)
+
+        # Function to copy/paste s3 access credentials from the portal.
+        def read_clipboard() -> None:
+            clipboard = QtGui.QGuiApplication.clipboard()
+            try:
+                credentials_with_opts = json.loads(clipboard.text())
+                for field, key in (
+                    (text_access_key, "accessKeyId"),
+                    (text_secret_key, "secretAccessKey"),
+                    (text_session_token, "sessionToken"),
+                    (text_host, "endpoint"),
+                    (text_bucket, "bucket"),
+                ):
+                    # Make sure that the value change is really registered (important for `bind`)
+                    field.setFocus()
+                    field.setText(credentials_with_opts[key])
+                    field.clearFocus()
+            except (json.JSONDecodeError, KeyError):
+                msg = NormalMessageBox(
+                    parent=box, window_title="Paste from clipboard failure"
+                )
+                msg.setIcon(QtWidgets.QMessageBox.Icon.Warning)
+                msg.setText(
+                    "This credential pasting is intended to be used with "
+                    "credentials copied from the portal.\n\n"
+                    "For the credentials pasting to work, the content of "
+                    "the clipboard must be a JSON string with the following "
+                    "format:\n\n"
+                    "{"
+                    '"accessKeyId": "value of access key ID", '
+                    '"secretAccessKey": "value of secret key", '
+                    '"sessionToken": "value of STS token", '
+                    '"endpoint": "S3 server endpoint", '
+                    '"bucket": "bucket name"'
+                    "}"
+                )
+                open_window(msg)
+
+        button = QtWidgets.QPushButton("Paste credentials from clipboard")
+        button.clicked.connect(read_clipboard)
+        button_layout = QtWidgets.QHBoxLayout()
+        button_layout.addStretch()
+        button_layout.addWidget(button)
+
         box = QtWidgets.QGroupBox()
         box.setFlat(True)
         grid_layout(
-            (MandatoryLabel("Host URL"), text_host),
-            (MandatoryLabel("Bucket"), text_bucket),
-            (MandatoryLabel("Access Key"), text_access_key),
-            (MandatoryLabel("Secret Key"), text_secret_key),
+            (
+                MandatoryLabel("Host"),
+                text_host,
+                secure_layout,
+            ),
+            (
+                MandatoryLabel("Bucket"),
+                text_bucket,
+            ),
+            (
+                MandatoryLabel("Access Key"),
+                GridLayoutCell(text_access_key, span=2),
+                MandatoryLabel("Secret Key"),
+                text_secret_key,
+            ),
+            (
+                QtWidgets.QLabel("Session Token"),
+                GridLayoutCell(text_session_token, span=4),
+            ),
+            (None, None, None, None, button_layout),
             parent=box,
         )
         return box
@@ -190,7 +282,7 @@ class TransferTab(BaseTab):
             parent=self,
             model=self.app_data.transfer_files,
         )
-        self.app_data.transfer_files.layoutChanged.connect(  # type: ignore
+        self.app_data.transfer_files.layoutChanged.connect(
             lambda: self.set_buttons_enabled(
                 self.app_data.transfer_files.rowCount() > 0
             )
@@ -283,9 +375,9 @@ class TransferTab(BaseTab):
             ("Save the current connection profile", save, True, "save"),
         ):
             action = Action(f":icon/feather/{icon}.png", tip, self)
-            action.triggered.connect(fn)  # type: ignore
+            action.triggered.connect(fn)
             if needs_selection:
-                connections_selection.currentTextChanged.connect(  # type: ignore
+                connections_selection.currentTextChanged.connect(
                     partial(set_btn_enabled, action)
                 )
                 if not connections_selection.currentText():
@@ -333,7 +425,7 @@ class TransferTab(BaseTab):
                 self.app_data.transfer_protocol_type
             ].target = connection
 
-        connections_selection.currentTextChanged.connect(load_connection)  # type: ignore
+        connections_selection.currentTextChanged.connect(load_connection)
 
         def toggle_protocol(btn: QtWidgets.QRadioButton, state: bool) -> None:
             protocol_name = TransferProtocol(btn.text()).name
@@ -343,7 +435,7 @@ class TransferTab(BaseTab):
                 )
             protocol_boxes[protocol_name].setVisible(state)
 
-        protocol_btn_grp.buttonToggled.connect(toggle_protocol)  # type: ignore
+        protocol_btn_grp.buttonToggled.connect(toggle_protocol)
 
         toolbar = ToolBar("Options", self)
         for action in self.create_conn_actions(connections_selection):
@@ -394,15 +486,15 @@ class TransferTab(BaseTab):
         msg_signal.msg.connect(show_second_factor_dialog)
         self.run_workflow_thread(
             transfer.transfer,
-            f_kwargs=dict(
-                files=self.app_data.transfer_files.stringList(),
-                protocol=protocol,
-                config=self.app_data.config,
-                dry_run=dry_run,
-                pkg_name_suffix=self.app_data.encrypt_package_name_suffix,
-                progress=GuiProgress(self.progress_bar.setValue),
-                two_factor_callback=second_factor_callback,
-            ),
+            f_kwargs={
+                "files": self.app_data.transfer_files.stringList(),
+                "protocol": protocol,
+                "config": self.app_data.config,
+                "dry_run": dry_run,
+                "pkg_name_suffix": self.app_data.encrypt_package_name_suffix,
+                "progress": GuiProgress(self.progress_bar.setValue),
+                "two_factor_callback": second_factor_callback,
+            },
             capture_loggers=(
                 transfer.logger,
                 protocols.sftp.logger,
@@ -431,8 +523,8 @@ class ConnectionDialog(QtWidgets.QDialog):
             QtWidgets.QDialogButtonBox.StandardButton.Ok
             | QtWidgets.QDialogButtonBox.StandardButton.Cancel
         )
-        btn_box.accepted.connect(self.accept)  # type: ignore
-        btn_box.rejected.connect(self.reject)  # type: ignore
+        btn_box.accepted.connect(self.accept)
+        btn_box.rejected.connect(self.reject)
 
         self.text_field = LineEdit()
         self.text_field.setValidator(
@@ -446,7 +538,7 @@ class ConnectionDialog(QtWidgets.QDialog):
             )
 
         set_ok_enabled(self.text_field.text())
-        self.text_field.textChanged.connect(set_ok_enabled)  # type: ignore
+        self.text_field.textChanged.connect(set_ok_enabled)
 
         self.setLayout(vbox_layout(QtWidgets.QLabel(label), self.text_field, btn_box))
 
