@@ -13,5 +13,5 @@ class Protocol(ABC):
     ) -> Any:
         ...
 
-    def required_password_args(self) -> Sequence[str]:  # pylint: disable=no-self-use
+    def required_password_args(self) -> Sequence[str]:
         return ()
