@@ -143,11 +143,6 @@ class Config:
         "configuration files.",
         file_type=FileType.directory,
     )
-    sign_encrypted_data: bool = field_ext(
-        default=True,
-        label="Sign encrypted data",
-        description="Whether encrypted data should be signed with sender's key.",
-    )
     always_trust_recipient_key: bool = field_ext(
         default=True,
         label="Always trust recipient key",
@@ -342,7 +337,7 @@ class Config:
 
 
 class ConnectionStore:
-    """Sftp/LiquidFiles connection configuration storage manager."""
+    """SFTP/S3/LiquidFiles connection configuration storage manager."""
 
     config_field_name = "connections"
 
@@ -496,6 +491,12 @@ def migrate_user_config_file() -> None:
     except UserError:
         return
 
+    # Migration to remove `sign_encrypted_data` from config.
+    # Migration added in December 2022, can be removed after about a year.
+    if "sign_encrypted_data" in config_dict:
+        del config_dict["sign_encrypted_data"]
+        config_needs_update = True
+
     # Migration to remove `offline` from config.
     # Migration added in October 2022, can be removed after about a year.
     if "offline" in config_dict:
