@@ -16,22 +16,27 @@ from typing import (
     TypeVar,
 )
 from itertools import repeat
+import abc
 
 
 class ProgressInterface:
     """Interface for progress objects."""
 
+    @abc.abstractmethod
     def update(self, completed_fraction: float) -> None:
         """Method to update the status of a progress object to a new
         fraction of completeness.
         :param float completed_fraction: fraction of completion value
             must be 0 <= completed_fraction <= 1.
         """
+        raise NotImplementedError
 
+    @abc.abstractmethod
     def get_completed_fraction(self) -> float:
         """Property to get the current completed fraction of the progress
         interface, i.e. the current fraction of completion of the task.
         """
+        raise NotImplementedError
 
 
 T = TypeVar("T")
