@@ -140,7 +140,6 @@ def encrypt(  # pylint: disable=too-many-statements
     with logger.log_task(
         f"Input data verification{' (dry_run)' if dry_run else ''}..."
     ):
-
         # Verify user has specified at least 1 file to encrypt and that the
         # file(s) have read permission for the user.
         logger.info("Verify files to encrypt")
@@ -209,6 +208,7 @@ def encrypt(  # pylint: disable=too-many-statements
             project_code = None
 
         logger.info("Verify available disk space")
+
         # The default value for the output name is based on date and time
         # when the script is being run.
         # Example output name: "20191011T145012.zip".
@@ -234,20 +234,23 @@ def encrypt(  # pylint: disable=too-many-statements
         ]
         check_paths_on_posix(archive_paths)
 
-        # If the user asked to sign the data, check that the GPG key password
-        # is correct.
-        if config.sign_encrypted_data and not dry_run:
-            logger.info("Verify data sender GPG password")
-            check_password(
-                password=enforce_passphrase(passphrase),
-                key_fingerprint=sender_pub_key.fingerprint,
-                gpg_store=config.gpg_store,
-            )
-
     if dry_run:
         logger.info("Dry run completed successfully")
         return None
 
+    # Verify the user's PGP key passphrase. The passphrase is needed to unlock
+    # the private PGP key used to sign the data.
+    # Note: the password is checked before starting to compress data, because
+    # that step can take a long time, and we don't want the workflow to fail
+    # at a later stage just because the user gave a wrong password.
+    logger.info("Verify data sender PGP key passphrase")
+    passphrase = enforce_passphrase(passphrase)
+    check_password(
+        password=passphrase,
+        key_fingerprint=sender_pub_key.fingerprint,
+        gpg_store=config.gpg_store,
+    )
+
     with logger.log_task("Compute sha256 checksum on input files..."):
         # Write input file checksums to a file that will be added to the
         # encrypted .tar.gz archive. This information must be encrypted as
@@ -264,7 +267,7 @@ def encrypt(  # pylint: disable=too-many-statements
     with logger.log_task("Compress and encrypt input data [this can take a while]..."):
         # Encryption is done with the recipient's public key and the optional
         # signing with the user's (i.e sender) private key. The user's private
-        # key passphrase is needed to sign the encrypted file.
+        # PGP key passphrase is needed to sign the encrypted file.
         encrypted_checksum_buf = io.StringIO()
         with delete_file_on_error(output_name), ZipFile(
             output_name, mode="w", compression=ZIP_STORED
@@ -303,12 +306,8 @@ def encrypt(  # pylint: disable=too-many-statements
                         recipients_fingerprint=[
                             key.fingerprint for key in recipients_pub_key
                         ],
-                        signature_fingerprint=sender_pub_key.fingerprint
-                        if config.sign_encrypted_data
-                        else None,
-                        passphrase=enforce_passphrase(passphrase)
-                        if config.sign_encrypted_data
-                        else None,
+                        signature_fingerprint=sender_pub_key.fingerprint,
+                        passphrase=passphrase,
                         always_trust=config.always_trust_recipient_key,
                     )
                 encrypted_checksum = encrypted_checksum_buf.read()
@@ -327,12 +326,11 @@ def encrypt(  # pylint: disable=too-many-statements
                 compression_algorithm="gzip" if compression_level > 0 else "",
             )
             metadata_bytes, metadata_signature_bytes = byte_encode_metadata(
-                metadata,
-                config.gpg_store,
-                passphrase,
-                sender_pub_key if config.sign_encrypted_data else None,
+                metadata=metadata,
+                gpg_store=config.gpg_store,
+                passphrase=passphrase,
+                sender_pub_key=sender_pub_key,
             )
-
             in_memory_files = (
                 (METADATA_FILE, metadata_bytes),
                 (METADATA_FILE_SIG, metadata_signature_bytes),
@@ -359,9 +357,12 @@ def check_arg_value(
     arg_name: str,
     arg_type_checker: Callable[[T], Any],
 ) -> None:
-    """Verify that the value of variable arg_value that is named arg_name is
-    following type arg_type. arg_type_checker is a function that does a check
-    of the type of the variable.
+    """Verify that the arg_value of variable arg_name is of type arg_type.
+
+    :param arg_value: value of the variable/argument - the object to check.
+    :param arg_name: name of the variable/argument to check.
+    :param arg_type_checker: function that does a check of the type of the variable.
+    :raises UserError: if value is of the wrong type.
     """
     try:
         arg_type_checker(arg_value)
